@@ -37,6 +37,17 @@ typedef struct __attribute__((aligned(CACHE_LINE_SIZE))) _conn_exchange_t {
 } conn_exchange_t;
 #endif // IDLE_THREADS
 
+typedef struct _thr_id_username_t {
+	uint32_t id;
+	char *username;
+} thr_id_usr;
+
+typedef struct _kill_queue_t {
+	pthread_mutex_t m;
+	std::vector<thr_id_usr *> conn_ids;
+	std::vector<thr_id_usr *> query_ids;
+} kill_queue_t;
+
 class ProxySQL_Poll {
 
   private:
@@ -200,6 +211,7 @@ class MySQL_Thread
 
 	int pipefd[2];
 	int shutdown;
+	kill_queue_t kq;
 
 	bool epoll_thread;
 	bool poll_timeout_bool;
@@ -234,7 +246,6 @@ class MySQL_Thread
 	struct {
 		bool stats_time_backend_query;
 		bool stats_time_query_processor;
-		bool query_cache_stores_empty_result;
 	} variables;
 
 #ifdef PROXYSQL_MYSQL_PTHREAD_MUTEX
@@ -262,6 +273,8 @@ class MySQL_Thread
 	MySQL_Connection * get_MyConn_local(unsigned int _hid, MySQL_Session *sess);
 	void push_MyConn_local(MySQL_Connection *);
 	void return_local_connections();
+	void Scan_Sessions_to_Kill(PtrArray *mysess);
+	void Scan_Sessions_to_Kill_All();
 };
 
 
@@ -416,7 +429,6 @@ class MySQL_Threads_Handler
 		int query_cache_size_MB;
 		bool stats_time_backend_query;
 		bool stats_time_query_processor;
-		bool query_cache_stores_empty_result;
 		bool kill_backend_connection_when_disconnect;
 	} variables;
 	struct {
@@ -486,6 +498,7 @@ class MySQL_Threads_Handler
 		return MLM->find_iface_from_fd(fd);
 	}
 	void Get_Memory_Stats();
+	void kill_connection_or_query(uint32_t _thread_session_id, bool query, char *username);
 };
 
 
