@@ -644,6 +644,7 @@ __thread bool mysql_thread___session_idle_show_processlist;
 __thread bool mysql_thread___sessions_sort;
 __thread bool mysql_thread___session_idle_ms;
 __thread bool mysql_thread___kill_backend_connection_when_disconnect;
+__thread int mysql_thread___hostgroup_manager_verbose;
 
 /* variables used for Query Cache */
 __thread int mysql_thread___query_cache_size_MB;
@@ -752,6 +753,7 @@ extern __thread bool mysql_thread___session_idle_show_processlist;
 extern __thread bool mysql_thread___sessions_sort;
 extern __thread bool mysql_thread___session_idle_ms;
 extern __thread bool mysql_thread___kill_backend_connection_when_disconnect;
+extern __thread int mysql_thread___hostgroup_manager_verbose;
 
 /* variables used for Query Cache */
 extern __thread int mysql_thread___query_cache_size_MB;
