@@ -1063,7 +1063,6 @@ bool MySQL_Protocol::generate_pkt_initial_handshake(bool send, void **ptr, unsig
 	if (mysql_thread___have_compress) {
 		mysql_thread___server_capabilities |= CLIENT_COMPRESS; // FIXME: shouldn't be here
 	}
-	mysql_thread___server_capabilities |= CLIENT_LONG_FLAG;
 	(*myds)->myconn->options.server_capabilities=mysql_thread___server_capabilities;
   memcpy(_ptr+l,&mysql_thread___server_capabilities, sizeof(mysql_thread___server_capabilities)); l+=sizeof(mysql_thread___server_capabilities);
   memcpy(_ptr+l,&mysql_thread___default_charset, sizeof(mysql_thread___default_charset)); l+=sizeof(mysql_thread___default_charset);
@@ -1233,9 +1232,8 @@ bool MySQL_Protocol::process_pkt_auth_swich_response(unsigned char *pkt, unsigne
 
 
 bool MySQL_Protocol::process_pkt_COM_CHANGE_USER(unsigned char *pkt, unsigned int len) {
-	// FIXME: very buggy function, it doesn't perform any real check
 	bool ret=false;
-  int cur=sizeof(mysql_hdr);
+	int cur=sizeof(mysql_hdr);
 	unsigned char *user=NULL;
 	char *password=NULL;
 	char *db=NULL;
@@ -1322,7 +1320,7 @@ bool MySQL_Protocol::process_pkt_COM_CHANGE_USER(unsigned char *pkt, unsigned in
 		free(sha1_pass);
 		sha1_pass=NULL;
 	}
-
+	userinfo->set(NULL,NULL,NULL,NULL); // just to call compute_hash()
 	return ret;
 }
 
@@ -1335,12 +1333,12 @@ bool MySQL_Protocol::process_pkt_handshake_response(unsigned char *pkt, unsigned
 	unsigned char *user=NULL;
 	char *db=NULL;
 	char *db_tmp = NULL;
-	unsigned char pass[128];
+	unsigned char *pass = NULL;
+	MySQL_Connection *myconn = NULL;
 	char *password=NULL;
 	bool use_ssl=false;
 	bool _ret_use_ssl=false;
 
-	memset(pass,0,128);
 	void *sha1_pass=NULL;
 //#ifdef DEBUG
 	unsigned char *_ptr=pkt;
@@ -1367,6 +1365,11 @@ bool MySQL_Protocol::process_pkt_handshake_response(unsigned char *pkt, unsigned
 	pkt     += strlen((char *)user) + 1;
 
 	pass_len = (capabilities & CLIENT_SECURE_CONNECTION ? *pkt++ : strlen((char *)pkt));
+	if (pass_len > (len - (pkt - _ptr))) {
+		ret = false;
+		goto __exit_process_pkt_handshake_response;
+	}
+	pass = (unsigned char *)malloc(pass_len+1);
 	memcpy(pass, pkt, pass_len);
 	pass[pass_len] = 0;
 
@@ -1461,7 +1464,7 @@ bool MySQL_Protocol::process_pkt_handshake_response(unsigned char *pkt, unsigned
             (capabilities & CLIENT_SECURE_CONNECTION ? "new" : "old"), user, password, pass, db, max_pkt, capabilities, charset, ((*myds)->encrypted ? "yes" : "no"));
 	assert(sess);
 	assert(sess->client_myds);
-	MySQL_Connection *myconn=sess->client_myds->myconn;
+	myconn=sess->client_myds->myconn;
 	assert(myconn);
 	myconn->set_charset(charset);
 	// enable compression
@@ -1495,6 +1498,7 @@ bool MySQL_Protocol::process_pkt_handshake_response(unsigned char *pkt, unsigned
 	}
 
 __exit_process_pkt_handshake_response:
+	free(pass);
 	if (password) {
 		free(password);
 		password=NULL;
@@ -1967,7 +1971,11 @@ void MySQL_ResultSet::add_err(MySQL_Data_Stream *_myds) {
 		char sqlstate[10];
 		sprintf(sqlstate,"%s",mysql_sqlstate(_mysql));
 		if (_myds && _myds->killed_at) { // see case #750
+			if (_myds->kill_type == 0) {
 			myprot->generate_pkt_ERR(false,&pkt.ptr,&pkt.size,sid,1907,sqlstate,(char *)"Query execution was interrupted, query_timeout exceeded");
+		} else {
+				myprot->generate_pkt_ERR(false,&pkt.ptr,&pkt.size,sid,1317,sqlstate,(char *)"Query execution was interrupted");
+			}
 		} else {
 			myprot->generate_pkt_ERR(false,&pkt.ptr,&pkt.size,sid,mysql_errno(_mysql),sqlstate,mysql_error(_mysql));
 		}
